# coding=utf-8
# Copyright 2018-2022 EVA
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
DISCRETE = 0
CONTINUOUS = 1
NO_GPU = -1
UNDEFINED_GROUP_ID = -1
# remove this when we implement the cacheable logic in the UDF itself
CACHEABLE_UDFS = ["YoloV5", "FaceDetector", "OCRExtractor"]
IFRAMES = "IFRAMES"
DEFAULT_FUNCTION_EXPRESSION_COST = 100
